%
%    FILE DESCRIBING FSU Monthly Averaged Wind Stresses (Unsmoothed) DATASET

% The preceeding blank line is important for cvs.
% $Id: fsun7.m,v 1.6 2000/03/17 16:57:30 dbyrne Exp $
%

% $Log: fsun7.m,v $
% Revision 1.6  2000/03/17 16:57:30  dbyrne
%
%
% Changed datanames so all indicate NSCAT origin of data.
%
% -- dbyrne 00/03/17
%
% Revision 1.5  1999/10/27 22:18:21  dbyrne
% *** empty log message ***
%
% Revision 1.3  1999/10/27 22:10:38  root
% Fixed many spelling and grammatical errors in comment fields.
%
% Revision 1.2  1999/10/27 21:09:31  root
% *** empty log message ***
%
% Revision 1.4  1999/09/21 13:50:53  paul
% changing catalog server to maewest...pdh
%
% Revision 1.3  1999/06/01 06:48:41  dbyrne
%
%
% updating things ...
%
% Revision 1.2  1999/05/21 17:46:23  paul
%  add DepthUnits = '';  .....  phemenway
%
% Revision 1.1  1999/05/21 16:55:51  paul
% Initial version....phemenway
%


% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';

% FUNCTIONS -- OPTIONAL
URL_m_File = 'fsun1u';
Cat_m_File = 'fsun7c';

% VARIABLES -- OPTIONAL
Server = ...
   'http://www.coaps.fsu.edu/cgi-bin/nph-nc/nscat/data/nc_monthlystress/';
%CatalogServer = ...
%  'http://koko.gso.uri.edu/cgi-bin/nph-ff/servers/nscat/fsu/fsu_nscat7fs.dat';
 CatalogServer = ...
  'http://maewest.gso.uri.edu/cgi-bin/nph-ff/catalog/fsunscat/fsu_nscat7fs.dat';

Nlon = 720;
Nlat = 360;

% The following are from daily data:
%IntervalTime = 24.0;
%MidTime = 12.0;

% VARIABLES -- REQUIRED
LonRange = [0.0 360.0];
LatRange = [-90.0 90.0];
TimeRange = [1996+283.5/366 1997+167/365];
DepthRange = [0 0];
Resolution = 111.0;
DepthUnits = '';

DataName = 'Wind - Gridded, Smoothed NSCAT Monthly Wind Stress - COAPS(FSU)';
LongitudeName = 'lon';
LatitudeName = 'lat';
TimeName = '';
DepthName = '';
SelectableVariables = str2mat('U_Wind_Stress','V_Wind_Stress');
DodsName = str2mat('tx','ty');
% note: DataNull is applied *before* scaling
DataNull = [nan nan nan nan 32767 32767];
DataScale = [0.0 1.0; 0.0 1.0; NaN NaN; NaN NaN; ...
               0.0  9.9999997e-5;  0.0  9.9999997e-5];
DataRange = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; -1.0 1.0; -1.0 1.0];

%COMMENTS
Comments1 = sprintf('%s\n', ...
'       COAPS NSCAT (Smoothed) Gridded Monthly Surface Wind Stresses', ...
' ', ...
' Global grids of half degree resolution, monthly averaged, surface wind', ...
' stress over water are available. The stresses are determined from NSCAT', ...
' observations through the use of David Weissman''s stress model function.', ...
' Two data sets are available: smoothed and unsmoothed.  These are the', ...
'  smoothed data.');

Comments2 = sprintf('%s\n', ...
'    ', ...
'    Units:   (N/m^2s) ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Month:1996/10 ', ...
'         Ending_Month:1997/6 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:0 ', ...
'              East Bounding Coordinate:360 ', ...
'              South Bounding Coordinate:-90 ', ...
'              North Bounding Coordinate:+90 ', ...
'    Point_of_Contact (Science) = ', ...
'            contact-name: Dr. Mark A. Bourassa', ...
'            contact-address1: Center for Ocean-Atmospheric Prediction Studies', ...
'            contact-address2: Florida State University', ...
'               contact-address3: Tallahassee, FL 32306-2840', ...
'               contact-country: USA', ...
'        contact-Telephone: (850) 644-6923', ...
'       contact-Electronic Mail Address:INTERNET > bourassa@coaps.fsu.edu', ...
'       contact-http: http://www.coaps.fsu.edu/~bourassa/', ...
'    ', ...
'    Point_of_Contact (Data Provision) = ', ...
'               name: Center for Ocean-Atmospheric Prediction Studies', ...
'               address1: Florida State University', ...
'               address2: Tallahassee, FL 32306-2840', ...
'               country: USA', ...
'               Telephone: (850) 644-6923', ...
'         Electronic Mail Address:INTERNET > bourassa@coaps.fsu.edu');

Comments = [Comments1 Comments2];

Acknowledge = sprintf('%s\n\n%s\n\n%s\n\n%s', ...
         ['The author of this dataset is M. A. Bourassa, bourassa@coaps.fsu.edu.'], ...
         ['The data are provided by the Center for Ocean-Atmospheric Prediction ', ...
          'Studies (COAPS), Florida State University, Tallahassee, ', ...
          'FL 32306-2840, bourassa@coaps.fsu.edu,'], ...
         ['and accessed via the Distributed Oceanographic Data ', ...
          'System (DODS: http://www.unidata.ucar.edu/packages/dods).'], ...
          ['Citation: ', ...
' Verschell, M. A., M. A. Bourassa, D. E. Weissman, and J. J. O''Brien,', ...
' 1998: Model Validation of the NASA Scatterometer Winds.', ...
' J. Geophys. Res., in press.']    );


Data_Use_Policy='';

